@@ -1409,16 +1409,21 @@ var MachinePresets map[string]*MachineGuest = map[string]*MachineGuest{
 	"dedicated-cpu-8x": {CPUKind: "dedicated", CPUs: 8, MemoryMB: 8 * MEMORY_MB_PER_CPU},
 }
 
+type MachineMetrics struct {
+	Port int    `toml:"port" json:"port"`
+	Path string `toml:"path" json:"path"`
+}
+
 type MachinePort struct {
-	Port       int      `json:"port"`
-	Handlers   []string `json:"handlers,omitempty"`
-	ForceHttps bool     `json:"force_https,omitempty"`
+	Port       int      `json:"port" toml:"port"`
+	Handlers   []string `json:"handlers,omitempty" toml:"handlers,omitempty"`
+	ForceHttps bool     `json:"force_https,omitempty" toml:"force_https,omitempty"`
 }
 
 type MachineService struct {
-	Protocol     string        `json:"protocol"`
-	InternalPort int           `json:"internal_port"`
-	Ports        []MachinePort `json:"ports"`
+	Protocol     string        `json:"protocol" toml:"protocol"`
+	InternalPort int           `json:"internal_port" toml:"internal_port"`
+	Ports        []MachinePort `json:"ports" toml:"ports"`
 }
 
 type MachineConfig struct {
@@ -1432,6 +1437,7 @@ type MachineConfig struct {
 	Services []MachineService  `json:"services,omitempty"`
 	VMSize   string            `json:"size,omitempty"`
 	Guest    *MachineGuest     `json:"guest,omitempty"`
+	Metrics  *MachineMetrics   `json:"metrics"`
 }
 
 type DeleteOrganizationMembershipPayload struct {
